@@ -21,6 +21,6 @@
 #ifndef GPE_XML_H
 #define GPE_XML_H
 
-osync_bool gpe_parse_settings(gpe_environment *env, char *data, int size);
+osync_bool gpe_parse_settings(gpe_environment *env, const char *data);
 
 #endif /* GPE_XML_H */
