@@ -1,6 +1,7 @@
 /*
  * gpe-sync - A plugin for the opensync framework
  * Copyright (C) 2005  Martin Felis <martin@silef.de>
+ * Copyright (C) 2007  Graham R. Cobb <g+opensync@cobb.uk.net>
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,7 +23,6 @@
 #ifndef TODO_H
 #define TODO_H
 
-osync_bool gpe_todo_get_changes(OSyncContext *ctx);
-void gpe_todo_setup(OSyncPluginInfo *info);
+osync_bool gpe_todo_setup(sink_environment *sinkenv, gpe_environment *env, OSyncPluginInfo *info, OSyncError **error);
 
 #endif /* TODO_H */
