@@ -1,6 +1,7 @@
 /*
  * gpe-sync - A plugin for the opensync framework
  * Copyright (C) 2005  Martin Felis <martin@silef.de>
+ * Copyright (C) 2007  Graham R. Cobb <g+opensync@cobb.uk.net>
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,7 +26,7 @@ int get_type_uid (const char *string);
 
 osync_bool parse_value_modified (char *string, char **uid, char **modified);
 
-osync_bool report_change (OSyncContext *ctx, gchar *type, gchar *uid, gchar *hash, gchar *data);
-
+osync_bool report_change (sink_environment *sinkenv, OSyncContext *ctx, gchar *type, gchar *uid, gchar *hash, char *string);
+void report_deleted (sink_environment *sinkenv, OSyncContext *ctx);
 
 #endif /* UTILS_H */
